@@ -1,3 +1,3 @@
 """Standard Controllers intended for subclassing by web developers"""
-from pylons.controllers.core import Controller, WSGIController
+from pylons.controllers.core import WSGIController
 from pylons.controllers.xmlrpc import XMLRPCController
