@@ -3,8 +3,8 @@ import logging
 
 from decorator import decorator
 
-import pylons
 from pylons.controllers.util import abort
+from pylons.decorators.util import get_pylons
 
 __all__ = ['dispatch_on', 'restrict']
 
@@ -15,7 +15,7 @@ def restrict(*methods):
 
     Example:
 
-    .. code-block:: Python
+    .. code-block:: python
 
         from pylons.decorators import rest
 
@@ -23,10 +23,11 @@ def restrict(*methods):
 
             @rest.restrict('GET')
             def comment(self, id):
+    
     """
     def check_methods(func, *args, **kwargs):
         """Wrapper for restrict"""
-        if pylons.request.method not in methods:
+        if get_pylons(args).request.method not in methods:
             log.debug("Method not allowed by restrict")
             abort(405, headers=[('Allow', ','.join(methods))])
         return func(*args, **kwargs)
@@ -35,14 +36,14 @@ def restrict(*methods):
 def dispatch_on(**method_map):
     """Dispatches to alternate controller methods based on HTTP method
 
-    Multiple keyword arguments should be passed, with the keyword corresponding
-    to the HTTP method to dispatch on (DELETE, POST, GET, etc.) and the
-    value being the function to call. The value should be a string indicating
-    the name of the function to dispatch to.
+    Multiple keyword arguments should be passed, with the keyword
+    corresponding to the HTTP method to dispatch on (DELETE, POST, GET,
+    etc.) and the value being the function to call. The value should be
+    a string indicating the name of the function to dispatch to.
 
     Example:
 
-    .. code-block:: Python
+    .. code-block:: python
 
         from pylons.decorators import rest
 
@@ -54,10 +55,11 @@ def dispatch_on(**method_map):
 
             def create_comment(self, id):
                 # Do something if its a post to comment
+    
     """
     def dispatcher(func, self, *args, **kwargs):
         """Wrapper for dispatch_on"""
-        alt_method = method_map.get(pylons.request.method)
+        alt_method = method_map.get(get_pylons(args).request.method)
         if alt_method:
             alt_method = getattr(self, alt_method)
             log.debug("Dispatching to %s instead", alt_method)
