@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 from paste.fixture import TestApp
 from paste.registry import RegistryManager
-import paste.httpexceptions as httpexceptions
+from webob.exc import status_map
 
 import pylons
 from pylons.controllers import WSGIController
@@ -32,8 +32,8 @@ class BasicWSGIController(WSGIController):
     
     def use_redirect(self):
         pylons.response.set_cookie('message', 'Hello World')
-        exc = httpexceptions.get_exception(301)
-        raise exc('/elsewhere')
+        exc = status_map[301]
+        raise exc('/elsewhere').exception
     
     def header_check(self):
         pylons.response.headers['Content-Type'] = 'text/plain'
@@ -42,6 +42,13 @@ class BasicWSGIController(WSGIController):
     def nothing(self):
         return
 
+    def params(self):
+        items = pylons.request.params.mixed().items()
+        items.sort()
+        return str(items)
+
+    def list(self):
+        return ['from', ' a ', 'list']
 
 class FilteredWSGIController(WSGIController):
     def __init__(self):
@@ -111,6 +118,12 @@ class TestBasicWSGI(TestWSGIController):
         assert resp.response.headers['Cache-Control'] == 'private'
         assert resp.header('Content-Type') == 'text/plain'
     
+    def test_head(self):
+        self.baseenviron['pylons.routes_dict']['action'] = 'header_check'
+        resp = self.app._gen_request('HEAD', '/')
+        assert '' == resp.body
+        assert resp.header('Content-Type') == 'text/plain'
+
     def test_redirect(self):
         self.baseenviron['pylons.routes_dict']['action'] = 'use_redirect'
         resp = self.app.get('/', status=301)
@@ -125,6 +138,19 @@ class TestBasicWSGI(TestWSGIController):
         self.baseenviron['pylons.routes_dict']['action'] = u'ОбсуждениеКомпаний'
         resp = self.app.get('/', status=404)
 
+    def test_params(self):
+        self.baseenviron['pylons.routes_dict']['action'] = u'params'
+        resp = self.app.get('/?foo=bar')
+        assert "[('foo', u'bar')]" in resp, str(resp)
+        resp = self.app.post('/?foo=bar', params=dict(snafu='snafoo'))
+        assert "[('foo', u'bar'), ('snafu', u'snafoo')]" in resp, str(resp)
+        resp = self.app.put('/?foo=bar', params=dict(snafu='snafoo'))
+        assert "[('foo', u'bar'), ('snafu', u'snafoo')]" in resp, str(resp)
+
+    def test_list(self):
+        self.baseenviron['pylons.routes_dict']['action'] = 'list'
+        assert 'from a list' in self.app.get('/')
+
 class TestFilteredWSGI(TestWSGIController):
     def __init__(self, *args, **kargs):
         TestWSGIController.__init__(self, *args, **kargs)
@@ -150,3 +176,7 @@ class TestFilteredWSGI(TestWSGIController):
     def test_after_string_response(self):
         resp = self.get_response(action='after_string_response')
         assert 'hello from __after__' in resp
+
+    def test_start_response(self):
+        self.baseenviron['pylons.routes_dict']['action'] = 'start_response'
+        self.app.get('/', status=404)
