@@ -2,36 +2,18 @@ import warnings
 from unittest import TestCase
 
 from paste.fixture import TestApp
+from paste.httpexceptions import HTTPMovedPermanently
 from paste.registry import RegistryManager
-from paste.wsgiwrappers import WSGIRequest
 
 import pylons
-from pylons import jsonify, Controller
+from pylons import jsonify, Response
 from pylons.controllers import WSGIController
+from pylons.controllers.util import etag_cache
 from pylons.decorators import jsonify as orig_jsonify
 from pylons.util import ContextObj
 
 from __init__ import ControllerWrap, SetupCacheGlobal, TestWSGIController
 
-class OldController(Controller):
-    def index(self):
-        return 'old'
-
-class TestDeprecatedControllerImport(TestCase):
-    def tearDown(self):
-        warnings.simplefilter('always', DeprecationWarning)
-    
-    def test_index(self):
-        warnings.simplefilter('error', DeprecationWarning)
-        self.environ = {'pylons.routes_dict':dict(action='index'),
-                        'paste.config':dict(global_conf=dict(debug=True))}
-        pylons.request._push_object(WSGIRequest(self.environ))
-        pylons.c._push_object(ContextObj())
-        try:
-            self.controller = OldController()
-        except DeprecationWarning, msg:
-            assert 'pylons.Controller has been moved' in msg[0]
-
 class SimpleTestWSGIController(TestWSGIController):
     wsgi_app = None
     def __init__(self, *args, **kargs):
@@ -99,6 +81,8 @@ class TestDeprecatedHelpers(SimpleTestWSGIController):
             assert ('The abort function has moved to pylons.controllers.util, '
                     'please update your import statements to reflect the '
                     'move') in msg[0], msg
+        else:
+            assert False, 'Expected a DeprecationWarning'
 
     def test_etag_cache(self):
         try:
@@ -107,6 +91,8 @@ class TestDeprecatedHelpers(SimpleTestWSGIController):
             assert ('The etag_cache function has moved to '
                     'pylons.controllers.util, please update your import '
                     'statements to reflect the move') in msg[0], msg
+        else:
+            assert False, 'Expected a DeprecationWarning'
 
     def test_redirect_to(self):
         try:
@@ -115,3 +101,82 @@ class TestDeprecatedHelpers(SimpleTestWSGIController):
             assert ('The redirect_to function has moved to '
                     'pylons.controllers.util, please update your import '
                     'statements to reflect the move') in msg[0], msg
+        else:
+            assert False, 'Expected a DeprecationWarning'
+
+
+class MiscLegacyController(WSGIController):
+
+    def legacy_httpexception(self):
+        raise HTTPMovedPermanently('/elsewhere')
+
+    def legacy_response(self):
+        return Response('Legacy Response!')
+
+    def legacy_etag_cache(self):
+        # used to crash
+        response = etag_cache('test')
+        response.body = 'from etag_cache'
+        return response
+
+
+class TestMiscLegacy(SimpleTestWSGIController):
+    wsgi_app = MiscLegacyController
+
+    def setUp(self):
+        SimpleTestWSGIController.setUp(self)
+        warnings.simplefilter('error', DeprecationWarning)
+
+    def tearDown(self):
+        SimpleTestWSGIController.tearDown(self)
+        warnings.simplefilter('always', DeprecationWarning)
+
+    def test_legacy_httpexception(self):
+        self.baseenviron['pylons.routes_dict']['action'] = \
+            'legacy_httpexception'
+        try:
+            self.app.get('/')
+        except DeprecationWarning, msg:
+            assert ('Raising a paste.httpexceptions.HTTPException is '
+                    'deprecated, use webob.exc.HTTPException instead') \
+                    in msg[0], msg
+        else:
+            assert False, 'Expected a DeprecationWarning'
+
+    def test_legacy_httpexception_to_response(self):
+        self.baseenviron['pylons.routes_dict']['action'] = \
+            'legacy_httpexception'
+        warnings.simplefilter('always', DeprecationWarning)
+        self.app.get('/', status=301)
+
+    def test_legacy_response_deprecated(self):
+        self.baseenviron['pylons.routes_dict']['action'] = 'legacy_response'
+        try:
+            self.app.get('/')
+        except DeprecationWarning, msg:
+            assert pylons.legacy.response_warning in msg[0], msg
+        else:
+            assert False, 'Expected a DeprecationWarning'
+
+    def test_legacy_response(self):
+        warnings.simplefilter('always', DeprecationWarning)
+
+        self.baseenviron['pylons.routes_dict']['action'] = 'legacy_response'
+        response = self.app.get('/')
+        assert 'Legacy Response!' in response
+
+    def test_legacy_etag_cache_deprecated(self):
+        self.baseenviron['pylons.routes_dict']['action'] = 'legacy_etag_cache'
+        try:
+            self.app.get('/')
+        except DeprecationWarning, msg:
+            assert pylons.legacy.response_warning in msg[0], msg
+        else:
+            assert False, 'Expected a DeprecationWarning'
+
+    def test_legacy_return_etag_cache(self):
+        warnings.simplefilter('always', DeprecationWarning)
+
+        self.baseenviron['pylons.routes_dict']['action'] = 'legacy_etag_cache'
+        response = self.app.get('/')
+        assert 'from etag_cache' in response
